#!/usr/bin/perl

# removes <fqdn>:80.cnf files for sites that have been deleted

use strict;
use Cobalt::Product;
use Cobalt::Email;
use Cobalt::Vsite;
use Cobalt::Meta::vsite;
use File::Basename;

my @vhosts = Cobalt::Vsite::vsite_list();
my $vhost;
my @fpxhosts;
my @fpxgroups;

foreach $vhost (@vhosts) {
        my @site = @$vhost; # (ip, hostname, group, webmaster email)

	my $vobj = new Cobalt::Meta::vsite;
	$vobj->retrieve(@site[2]);
	
	if ($vobj->get('fpx') eq 'on') { 
	    push @fpxhosts, @site[1];
	    push @fpxgroups, @site[2];
	}
    }
my @cnffiles = glob("$Fpx_cnfdir/*80.cnf");
foreach my $cnf (@cnffiles) {
    my $keep = 0;
    foreach my $fpxhost (@fpxhosts) {
	if ("$fpxhost:80.cnf" eq basename($cnf)) {
		$keep = 1;
	    last; # break out 
	    
	}
    }
    if (!$keep) {
	print "Deleting unused frontpage cnf file: $cnf\n";
	unlink "$cnf";
    }
}

# for sites which have fp enabled but no vti dirs i.e. broken by reusing name
# - remove fp flag from db
# - remove fqdn:80.cnf file from /usr/local/frontpage
foreach my $fpxgroup (@fpxgroups) {
    if (!-e "$Userdir/$fpxgroup/$Webdir/_vti_bin") {
	print "Removing /usr/local/frontpage cnf and db flags for $fpxgroup\n";
	my($siteName)=(Cobalt::Vsite::vsite_get_bygroup($fpxgroup))[1];
	
	unlink "$Fpx_cnfdir/$siteName:80.cnf";
	Cobalt::Meta::update("type"   => "vsite",
			     "change" => ["fpx", "f"],
			     "where"  => ["name", "=", "$fpxgroup"]);
	Cobalt::Meta::update("type"   => "users",
			     "change" => ["fpx", "f"],
			     "where"  => ["vsite", "=", "$fpxgroup"]);
	
    }
}

   
